ZCursor

Struct ZCursor 

pub struct ZCursor<T> {
    pub(crate) stream: T,
    pub(crate) position: usize,
}
Wraps an in memory buffer providing it with a Seek method but works in no_std environments

std::io::Cursor is available in std environments, but we also need support for no_std environments so this serves as a drop in replacement

Fields

stream: Tposition: usize

Implementations

Source

impl<T: AsRef<[u8]>> ZCursor<T>

pub fn new(buffer: T) -> ZCursor<T>

Source

impl<T: AsRef<[u8]>> ZCursor<T>

pub fn skip(&mut self, num: usize)

Move forward num bytes from the current position.

It doesn’t check that position overflowed, new position may point past the internal buffer, all subsequent reads will either return an error or zero depending on the method called

pub fn rewind(&mut self, num: usize)

Move back num bytes from the current position

This saturates at zero, it can never be negative or wraparound when the value becomes too small

pub fn split(&self) -> (&[u8], &[u8])

Source

impl<T: AsRef<[u8]>> ZCursor<T>

pub(crate) fn read_byte_no_error_impl(&mut self) -> u8

pub(crate) fn read_exact_bytes_impl( &mut self, buf: &mut [u8], ) -> Result<(), ZByteIoError>

pub(crate) fn read_const_bytes_impl<const N: usize>( &mut self, buf: &mut [u8; N], ) -> Result<(), ZByteIoError>

pub(crate) fn read_const_bytes_no_error_impl<const N: usize>( &mut self, buf: &mut [u8; N], )

pub(crate) fn read_bytes_impl( &mut self, buf: &mut [u8], ) -> Result<usize, ZByteIoError>

pub(crate) fn peek_bytes_impl( &mut self, buf: &mut [u8], ) -> Result<usize, ZByteIoError>

pub(crate) fn peek_exact_bytes_impl( &mut self, buf: &mut [u8], ) -> Result<(), ZByteIoError>

pub(crate) fn z_seek_impl( &mut self, from: ZSeekFrom, ) -> Result<u64, ZByteIoError>

pub(crate) fn is_eof_impl(&mut self) -> Result<bool, ZByteIoError>

pub(crate) fn z_position_impl(&mut self) -> Result<u64, ZByteIoError>

pub(crate) fn read_remaining_impl( &mut self, sink: &mut Vec<u8>, ) -> Result<usize, ZByteIoError>